# frozen_string_literal: true

require 'rest-client'
require 'json'
require 'uri'

module Splinter
  class API
    BASE_URL = 'https://ninja-bot.treehoppr.com/api/beta'

    def self.get(endpoint)
      response = RestClient.get(build_url(endpoint), headers)
      JSON.parse(response.body)
    end

    def self.paginated_get(endpoint, params = {})
      url = build_url(endpoint, params)
      results = []

      loop do
        result = RestClient.get(url, headers)
        parsed_result = JSON.parse(result.body)
        results.concat(parsed_result['results'])
        url = parsed_result.dig('next')
        break if url.nil?
      end

      results
    end

    def self.headers
      { 'Authorization': "Token #{Splinter.configuration.api_key}" }
    end

    def self.build_url(endpoint, params = {})
      url = "#{BASE_URL}/#{endpoint}"
      url += "?#{URI.encode_www_form(params)}" unless params.empty?

      url
    end
  end
end
